@@ -14,6 +14,10 @@ import os
 import sys
 from sphinx.deprecation import RemovedInSphinx40Warning
 
+with open("README.md", "r") as readme_file:
+    readme = readme_file.read()
+exec(open('../dandelion/version.py').read())
+
 sys.path.insert(0, os.path.abspath('..'))
 sys.path.insert(0, os.path.abspath('.'))
 
@@ -26,7 +30,7 @@ copyright = '2020, zktuong'
 author = 'zktuong'
 
 # The full version, including alpha/beta/rc tags
-release = '0.0.27.post1'
+release = __version__
 
 # -- General configuration ---------------------------------------------------
 
